/* OZZuul.h created by bungi on Wed 11-Feb-1998 */

#import <AppKit/AppKit.h>

#import <OmniFoundation/OFSignature.h>

#import "FrameworkDefines.h"

// This notification will get sent if too many applications are running
// this application.  This notification will get posted in the main
// thread.
OmniZuul_EXTERN NSString *OZTooManyApplicationsRunningNotification;
OmniZuul_EXTERN NSString   *OZApplicationHostsKey; // userInfo key for name of hosts running app

typedef enum _OZValidationState {
    OmniZuulStillChecking,
    OmniZuulValidated,
    OmniZuulNoAvailableLicense
} OZValidationState;

typedef struct _OZNetworkAddress {
    // The address formed should be 'a.b.c.d'
    unsigned char a, b, c, d;
} OZNetworkAddress;

typedef struct _OZApplicationInfo {
    unsigned int     applicationId;
    OZNetworkAddress applicationHost;  // actually an IP Multicast address
    unsigned short   applicationPort;
    unsigned char    applicationData[OF_SIGNATURE_LENGTH];
} OZApplicationInfo;

@class OZRuntimeLicense;

@protocol OZLicenseDelegate
- (const void *) applicationInfo;
// This actually should return a OZApplicationInfo, but there is no sense
// including the definition of this structure in the ObjC runtime if we
// don't have to...

- (void) licenseStateChanged;
// This is sent in the main thread when the licensing state of
// OZZuul has changed.

@end

@class OZRuntimeLicense;

@interface OZZuul : NSObject
{
    NSArray                      *licenseSearchPath;
    NSDictionary                 *licenseTypeTranslations;
    NSDictionary                 *licenseKeyInfo;
    NSArray                      *licenseFileKeys;
    NSObject <OZLicenseDelegate> *licenseDelegate;
    OZRuntimeLicense             *licenseTaken;
    
    NSConditionLock              *retryLock;
    
    NSRecursiveLock              *lock;
    NSMutableSet                 *locked_licenses;
    NSMutableArray               *locked_sortedLicenses;
    OZValidationState             locked_state;

    IBOutlet NSPanel             *panel;
    IBOutlet NSTextField         *statusField;
    IBOutlet NSTableView         *licenseTableView;
    IBOutlet NSTableColumn       *seatsColumn;
    IBOutlet NSTableColumn       *ownerColumn;
    IBOutlet NSTableColumn       *dateEnteredColumn;
    IBOutlet NSTableColumn       *dateExpiresColumn;
    IBOutlet NSButton            *deleteButton;
    

    IBOutlet NSPanel             *addPanel;
    IBOutlet NSPopUpButton       *licenseTypePopUp;
    IBOutlet NSTableView         *licenseKeyValueTableView;
    IBOutlet NSTableColumn       *licenseKeyColumn;
    IBOutlet NSTableColumn       *licenseValueColumn;
    IBOutlet NSButton            *saveButton;
    IBOutlet NSTextField         *ownerTextField;
    IBOutlet NSTextField         *licenseKeyTextField;

    NSMutableDictionary          *currentLicenseDictionary;
}

+ (OZZuul *) sharedZuul;

- (BOOL) check;
/*
 This can be used by applications as a real quick way to abort operations
 that require a valid license.  This will return YES if there is a valid
 license or if we are still checking.  This means that the user could
 possibly start some operations BEFORE the licensing state is fully
 determined.  So, you should check not only in the 'open'/'create' phase
 of your operations but also in the 'save'/'print' or other followup operations.
 If this returns NO, a error panel will be displayed and the license panel will
 be brought up.
 */

- (NSObject <OZLicenseDelegate> *) licenseDelegate;
- (void) setLicenseDelegate: (NSObject <OZLicenseDelegate> *) aDelegate;

- (void) startValidation;

- (NSArray *) licenseSearchPath;
- (void) setLicenseSearchPath: (NSArray *) path;

- (NSDictionary *) licenseTypeTranslations;
- (void) setLicenseTypeTranslations: (NSDictionary *) dict;

- (OZValidationState) validationState;
- (OZRuntimeLicense *) licenseTaken;

- (void) importLicenseFileAtPath: (NSString *) path;

- (void) cacheLicense: (OZRuntimeLicense *) license;
- (void) uncacheLicense: (OZRuntimeLicense *) license;
- (BOOL) licenseIsCached: (OZRuntimeLicense *) license;

- (Class) valueClassForKey: (NSString *) key;
- (id) coerceString: (NSString *) string toValueClass: (Class) aClass;
- (id) coerceString: (NSString *) string toValueClassForKey: (NSString *) key;

//
// IB actions
//

// This is hooked up automatically
- (IBAction) showLicenses: (id) sender;

- (IBAction) addLicense: (id) sender;
- (IBAction) saveLicense: (id) sender;
- (IBAction) cancelLicense: (id) sender;
- (IBAction) deleteLicense: (id) sender;
- (IBAction) importLicenseFile: (id) sender;

@end
